@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-
+import os
 import json
 
 import requests
@@ -8,9 +8,8 @@ import requests
 from .exception import WeChatWorkSDKException
 from .mixin import ValidationMixin
 
-
 # 企业微信API根URL
-WECHATWORK_API_ROOT_URL = 'https://qyapi.weixin.qq.com/cgi-bin/'
+WECHATWORK_API_ROOT_URL = os.environ.get('WECHATWORK_API_ROOT_URL', 'https://qyapi.weixin.qq.com/cgi-bin/')
 
 
 def get_access_token(corpid, secret) -> (str, int):
@@ -22,7 +21,7 @@ def get_access_token(corpid, secret) -> (str, int):
         - access_token: 获取到的凭证，最长为512字节
         - expires_in: 凭证的有效时间（秒），通常为7200
     """
-    url = WECHATWORK_API_ROOT_URL + 'gettoken?corpid={corpid}&corpsecret={secret}'\
+    url = WECHATWORK_API_ROOT_URL + 'gettoken?corpid={corpid}&corpsecret={secret}' \
         .format(corpid=corpid, secret=secret)
     data = json.loads(requests.get(url).content)
     if int(data['errcode']) == 0:
@@ -64,9 +63,6 @@ class WeChatWorkSDK(ValidationMixin):
         self._access_token = None
 
     def request_api(self, method, api, query_params=None, data=None):
-        # 验证数据
-        self.validate(**{**query_params, **data})
-
         # 拼接API的URL
         url = self.API_ROOT_URL + api
 
@@ -104,4 +100,19 @@ class WeChatWorkSDK(ValidationMixin):
         return self.request_api('POST', api, query_params, data)
 
 
+if __name__ == '__main__':
+    data = {
+        "touser": "@all",
 
+        "msgtype": "text",
+        "agentid": 1000002,
+        "text": {
+            "content": "这是一条通知"
+        },
+        "safe": 0,
+        "enable_id_trans": 0,
+        "enable_duplicate_check": 0
+    }
+
+    we = WeChatWorkSDK('wwc18433f3075302e4', 'iL_8JXBoB5vFITCcOk2-EvP6TcOnVCjZI1LRw8vidtE')
+    we.request_api('post', '/message/send', query_params={}, data=data)
